@@ -28,8 +28,7 @@
 #define IS_CONNECTED(connection,return_value) {if (!connection->priv->wcap_session_id) return return_value;}
 #define NEW_URI(uri) {uri = soup_uri_new (connection->priv->server_uri); \
 		if (uri && uri->path) {g_free (uri->path); uri->path = NULL;} \
-		if (uri && uri->query) {g_free (uri->query); uri->query = NULL;}}	\
-		if (uri) uri->broken_encoding = TRUE;
+		if (uri && uri->query) {g_free (uri->query); uri->query = NULL;}}
 #define IS_CNC_WCAP_2_0(connection) ( !strncmp (connection->priv->wcap_version, "2.0", 3) )
 
 struct _SunOneConnectionPrivate {
@@ -88,7 +87,7 @@ query_encode (const char *part, gboolean escape_unsafe,
 }
 
 static void
-append_to_query (SoupUri *uri, const char *param, const char *value)
+append_to_query (SoupURI *uri, const char *param, const char *value)
 {
 	char *tmp, *enc;
 	
@@ -104,7 +103,7 @@ append_to_query (SoupUri *uri, const char *param, const char *value)
 }
 
 static void
-append_to_query_int (SoupUri *uri, const char *param, int value)
+append_to_query_int (SoupURI *uri, const char *param, int value)
 {
 	char *tmp;
 	
@@ -136,7 +135,7 @@ get_stringv (const char **stringv)
 
 
 static void
-append_to_query_stringv (SoupUri *uri, const char *param, const char **stringv)
+append_to_query_stringv (SoupURI *uri, const char *param, const char **stringv)
 {
 	char *string;
 	
@@ -151,7 +150,7 @@ append_to_query_stringv (SoupUri *uri, const char *param, const char **stringv)
 }
 
 static void
-append_to_query_text (SoupUri *uri, const char *param, ECalComponentText *text)
+append_to_query_text (SoupURI *uri, const char *param, ECalComponentText *text)
 {
 	if (text->value)
 		append_to_query (uri, param, text->value);
@@ -160,7 +159,7 @@ append_to_query_text (SoupUri *uri, const char *param, ECalComponentText *text)
 }
 
 static void
-append_to_query_text_list (SoupUri *uri, const char *param, GSList *text_list)
+append_to_query_text_list (SoupURI *uri, const char *param, GSList *text_list)
 {
 	GSList *l;
 	char *string;
@@ -185,7 +184,7 @@ append_to_query_text_list (SoupUri *uri, const char *param, GSList *text_list)
 }
 
 static void
-append_to_query_datetime (SoupUri *uri, const char *param, ECalComponentDateTime *dt, gboolean zero)
+append_to_query_datetime (SoupURI *uri, const char *param, ECalComponentDateTime *dt, gboolean zero)
 {
 	const char *string;
 
@@ -201,7 +200,7 @@ append_to_query_datetime (SoupUri *uri, const char *param, ECalComponentDateTime
 }
 
 static void
-append_to_query_attendees (SoupUri *uri, const char *param, GSList *attendee_list, SunOneConnection *connection, const char *calid, const char *email)
+append_to_query_attendees (SoupURI *uri, const char *param, GSList *attendee_list, SunOneConnection *connection, const char *calid, const char *email)
 {
 	GSList *l;
 	GString *string;
@@ -331,7 +330,7 @@ append_to_query_attendees (SoupUri *uri, const char *param, GSList *attendee_lis
 }
 
 static void
-append_to_query_exdate_list (SoupUri *uri, const char *param, GSList *dt_list)
+append_to_query_exdate_list (SoupURI *uri, const char *param, GSList *dt_list)
 {
 	GSList *l;
 	char *string;
@@ -358,7 +357,7 @@ append_to_query_exdate_list (SoupUri *uri, const char *param, GSList *dt_list)
 }
 
 static void
-append_to_query_recur_list (SoupUri *uri, const char *param, GSList *r_list)
+append_to_query_recur_list (SoupURI *uri, const char *param, GSList *r_list)
 {
 	GSList *l;
 	char *string;
@@ -384,7 +383,7 @@ append_to_query_recur_list (SoupUri *uri, const char *param, GSList *r_list)
 }
 
 static void
-append_to_query_classification (SoupUri *uri, const char *param, ECalComponentClassification class)
+append_to_query_classification (SoupURI *uri, const char *param, ECalComponentClassification class)
 {
 	switch (class) {
 	case E_CAL_COMPONENT_CLASS_PUBLIC:
@@ -403,7 +402,7 @@ append_to_query_classification (SoupUri *uri, const char *param, ECalComponentCl
 
 
 static void
-append_to_query_status (SoupUri *uri, const char *param, icalproperty_status status)
+append_to_query_status (SoupURI *uri, const char *param, icalproperty_status status)
 {
 	switch (status) {
 	case ICAL_STATUS_CONFIRMED:
@@ -436,7 +435,7 @@ append_to_query_status (SoupUri *uri, const char *param, icalproperty_status sta
 }
 
 static void
-append_to_query_compstate (SoupUri *uri, const char *param, SunOneCompState state)
+append_to_query_compstate (SoupURI *uri, const char *param, SunOneCompState state)
 {
 	const char *statev[7];
 	int i;
@@ -471,7 +470,7 @@ append_to_query_compstate (SoupUri *uri, const char *param, SunOneCompState stat
 }
 
 static void
-append_to_query_geo (SoupUri *uri, const char *param, struct icalgeotype *geo)
+append_to_query_geo (SoupURI *uri, const char *param, struct icalgeotype *geo)
 {
 	char *tmp;
 	
@@ -484,7 +483,7 @@ append_to_query_geo (SoupUri *uri, const char *param, struct icalgeotype *geo)
 }
 
 static void
-append_to_query_alarms (SoupUri *uri, SunOneConnection *connection, ECalComponent *comp)
+append_to_query_alarms (SoupURI *uri, SunOneConnection *connection, ECalComponent *comp)
 {
 	GList *auids, *l;
 	ECalComponentAlarm *alarm;
@@ -632,7 +631,7 @@ parse_session_object (SunOneConnection *connection, SoupMessage *msg)
 
 	g_return_val_if_fail (msg != NULL, FALSE);
 
-	icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
+	icalcomp = sunone_util_icalparser_parse_string (msg->response_body->data, msg->response_body->length);
 	if (!icalcomp)
 		return FALSE;
 
@@ -668,7 +667,7 @@ static guint
 sunone_login (SunOneConnection *connection, gboolean refresh)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *login_uri;
+	SoupURI *login_uri;
 	SoupMessage *msg;
 	icalcomponent *icalcomp;
 	guint error_code = SOUP_STATUS_CANT_CONNECT;
@@ -708,7 +707,7 @@ sunone_login (SunOneConnection *connection, gboolean refresh)
 		}
 	}
 	/* parse the returned data */
-	icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
+	icalcomp = sunone_util_icalparser_parse_string (msg->response_body->data, msg->response_body->length);
 	g_object_unref (msg);
 	soup_uri_free (login_uri);
 	if (icalcomp) {
@@ -743,7 +742,7 @@ static guint
 sunone_logout (SunOneConnection *connection)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *logout_uri;
+	SoupURI *logout_uri;
 	SoupMessage *msg;
 	guint error_code;
 
@@ -881,7 +880,7 @@ sunone_connection_new (const char *server_uri, const char *proxy_uri,
 {
 	SunOneConnection *connection;
 	SunOneConnectionPrivate *priv;
-	SoupUri *suri;
+	SoupURI *suri;
 
 	connection = g_object_new (SUNONE_CONNECTION_TYPE, NULL);
 	priv = connection->priv;
@@ -1094,7 +1093,7 @@ SunOneConnectionPreferences *
 sunone_connection_get_preferences (SunOneConnection *connection)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *get_uri;
+	SoupURI *get_uri;
 	SoupMessage *msg;
 	guint ret;
 	icalcomponent *icalcomp;
@@ -1133,7 +1132,7 @@ sunone_connection_get_preferences (SunOneConnection *connection)
 	}
 
 	/* parse the returned data */
-	icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
+	icalcomp = sunone_util_icalparser_parse_string (msg->response_body->data, msg->response_body->length);
 	g_object_unref (msg);
 	if (!icalcomp) {
 		g_static_mutex_unlock (&mutex);
@@ -1257,7 +1256,7 @@ guint
 sunone_connection_set_preferences (SunOneConnection *connection, SunOneConnectionPreferences *prefs)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *set_uri;
+	SoupURI *set_uri;
 	SoupMessage *msg;
 	gchar *s, *s1 = NULL;
 	guint retval;
@@ -1385,7 +1384,7 @@ guint
 sunone_connection_createcalendar (SunOneConnection *connection, const gchar *calid, gchar **real_calid)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *suri;
+	SoupURI *suri;
 	SoupMessage *msg;
 	guint retval;
 	GList *acls = NULL;
@@ -1426,7 +1425,7 @@ sunone_connection_createcalendar (SunOneConnection *connection, const gchar *cal
 		icalcomponent *icalcomp;
 
 		/* parse the response to get the calid as generated in the server */
-		icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
+		icalcomp = sunone_util_icalparser_parse_string (msg->response_body->data, msg->response_body->length);
 		if (icalcomp) {
 			icalproperty *icalprop;
 
@@ -1491,7 +1490,7 @@ guint
 sunone_connection_deletecalendar (SunOneConnection *connection, const gchar *calid)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *suri;
+	SoupURI *suri;
 	SoupMessage *msg;
 	guint retval;
 	SunOneConnectionPreferences *prefs;
@@ -1639,7 +1638,7 @@ sunone_connection_get_calprops (SunOneConnection *connection, const gchar *calid
 	SunOneConnectionPrivate *priv = connection->priv;
 	gchar *calid_hash = NULL;
 	SunOneCalendarProperties *calprops = NULL;
-	SoupUri *get_uri;
+	SoupURI *get_uri;
 	SoupMessage *msg;
 	icalcomponent *icalcomp;
 	SunOneCalendarProperties *clone;
@@ -1674,7 +1673,7 @@ sunone_connection_get_calprops (SunOneConnection *connection, const gchar *calid
 		}
 
 		/* parse the returned data */
-		icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
+		icalcomp = sunone_util_icalparser_parse_string (msg->response_body->data, msg->response_body->length);
 		g_object_unref (msg);
 		if (!icalcomp) {
 			g_static_mutex_unlock (&mutex);
@@ -1762,7 +1761,7 @@ sunone_connection_set_calprops (SunOneConnection *connection,
 				SunOneCalendarProperties *calprops)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *set_uri;
+	SoupURI *set_uri;
 	SoupMessage *msg;
 	guint retval;
 	gchar *s;
@@ -1820,7 +1819,7 @@ GList *
 sunone_connection_list_calids (SunOneConnection *connection)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *get_uri;
+	SoupURI *get_uri;
 	SoupMessage *msg;
 	icalcomponent *icalcomp, *subcomp;
 	SunOneCalendarProperties *calprops;
@@ -1843,7 +1842,7 @@ sunone_connection_list_calids (SunOneConnection *connection)
 	soup_uri_free (get_uri);
 
 	if (SUNONE_ERROR_IS_SUCCESSFUL (msg->status_code)) {
-		icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
+		icalcomp = sunone_util_icalparser_parse_string (msg->response_body->data, msg->response_body->length);
 		if (icalcomp) {
 			subcomp = icalcomponent_get_first_component (icalcomp, ICAL_VCALENDAR_COMPONENT);
 			while (subcomp) {
@@ -1869,7 +1868,7 @@ GList *
 sunone_connection_search_calids (SunOneConnection *connection, SunOneSearchField field, SunOneSearchBy by, const char *search_str)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *get_uri;
+	SoupURI *get_uri;
 	SoupMessage *msg;
 	icalcomponent *icalcomp, *subcomp;
 	SunOneCalendarProperties *calprops;
@@ -1909,7 +1908,7 @@ sunone_connection_search_calids (SunOneConnection *connection, SunOneSearchField
 		char *tmp_str;
 		char *vcal_str;
 
-		tmp_str = g_strndup (msg->response.body, msg->response.length);
+		tmp_str = g_strndup (msg->response_body->data, msg->response_body->length);
 		if (tmp_str) {
 			vcal_str = g_strdup_printf ("BEGIN:VCALENDAR\n%s\nEND:VCALENDAR\n", tmp_str);
 			g_free (tmp_str);
@@ -1970,7 +1969,7 @@ sunone_connection_get_all_timezones (SunOneConnection *connection,
 				     icalcomponent **icalcomp)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *fetch_uri;
+	SoupURI *fetch_uri;
 	SoupMessage *msg;
 	guint retval;
 
@@ -1991,7 +1990,7 @@ sunone_connection_get_all_timezones (SunOneConnection *connection,
 	retval = msg->status_code;
 
 	if (SUNONE_ERROR_IS_SUCCESSFUL (msg->status_code)) {
-		*icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
+		*icalcomp = sunone_util_icalparser_parse_string (msg->response_body->data, msg->response_body->length);
 		if (!*icalcomp)
 			retval = SOUP_STATUS_MALFORMED;
 	}
@@ -2011,7 +2010,7 @@ sunone_connection_deletetodos_by_id (SunOneConnection *connection,
 				     SunOneModType mod)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *fetch_uri;
+	SoupURI *fetch_uri;
 	SoupMessage *msg;
 	guint retval;
 
@@ -2047,7 +2046,7 @@ sunone_connection_deleteevents_by_id (SunOneConnection *connection,
 				      SunOneModType mod)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *fetch_uri;
+	SoupURI *fetch_uri;
 	SoupMessage *msg;
 	guint retval;
 
@@ -2122,7 +2121,7 @@ sunone_connection_fetchcomponents_by_lastmod (SunOneConnection *connection,
 					      time_t *server_time)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *fetch_uri;
+	SoupURI *fetch_uri;
 	SoupMessage *msg;
 	guint retval;
 
@@ -2150,14 +2149,14 @@ sunone_connection_fetchcomponents_by_lastmod (SunOneConnection *connection,
 	retval = msg->status_code;
 
 	if (SUNONE_ERROR_IS_SUCCESSFUL (msg->status_code)) {
-		*icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
+		*icalcomp = sunone_util_icalparser_parse_string (msg->response_body->data, msg->response_body->length);
 		if (!*icalcomp)
 			retval = SOUP_STATUS_MALFORMED;
 
 		if (server_time) {
 			const char *date;
 			
-			date = soup_message_get_header (msg->response_headers, "Date");
+			date = soup_message_headers_get (msg->response_headers, "Date");
 			*server_time = parse_http_date (date);
 			if (*server_time < 0)
 				*server_time = 0;
@@ -2179,7 +2178,7 @@ sunone_connection_fetch_deletedcomponents (SunOneConnection *connection,
 				icalcomponent **icalcomp)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *fetch_uri;
+	SoupURI *fetch_uri;
 	SoupMessage *msg;
 	guint retval;
 
@@ -2206,7 +2205,7 @@ sunone_connection_fetch_deletedcomponents (SunOneConnection *connection,
 	retval = msg->status_code;
 
 	if (SUNONE_ERROR_IS_SUCCESSFUL (msg->status_code)) {
-		*icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
+		*icalcomp = sunone_util_icalparser_parse_string (msg->response_body->data, msg->response_body->length);
 		if (!*icalcomp)
 			retval = SOUP_STATUS_MALFORMED;
 	}
@@ -2225,7 +2224,7 @@ sunone_connection_get_freebusy (SunOneConnection *connection,
 				icalcomponent **icalcomp)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *fetch_uri;
+	SoupURI *fetch_uri;
 	SoupMessage *msg;
 	guint retval;
 
@@ -2248,7 +2247,7 @@ sunone_connection_get_freebusy (SunOneConnection *connection,
 	retval = msg->status_code;
 
 	if (SUNONE_ERROR_IS_SUCCESSFUL (msg->status_code)) {
-		*icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
+		*icalcomp = sunone_util_icalparser_parse_string (msg->response_body->data, msg->response_body->length);
 		if (!*icalcomp)
 			retval = SOUP_STATUS_MALFORMED;
 	}
@@ -2275,7 +2274,7 @@ sunone_connection_get_freebusy (SunOneConnection *connection,
 		retval = msg->status_code;
 
 		if (SUNONE_ERROR_IS_SUCCESSFUL (msg->status_code)) {
-			*icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
+			*icalcomp = sunone_util_icalparser_parse_string (msg->response_body->data, msg->response_body->length);
 			if (!*icalcomp)
 				retval = SOUP_STATUS_MALFORMED;
 		}
@@ -2292,7 +2291,7 @@ guint
 sunone_connection_import (SunOneConnection *connection, const char *calid, icalcomponent *icalcomp)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *uri;
+	SoupURI *uri;
 	SoupMessage *msg;
 	guint retval;
 	char *ical_string, *import_msg, *content_type, *err;
@@ -2319,7 +2318,7 @@ sunone_connection_import (SunOneConnection *connection, const char *calid, icalc
 	import_msg = g_strdup_printf ("-----------------------------33111928916708\r\nContent-Disposition: form-data; name=\"Upload\"; filename=\"ical1.ics\"\r\n\r\n%s-----------------------------33111928916708--", ical_string);
 	
 	content_type = "multipart/form-data;boundary=---------------------------33111928916708";	
-	msg = sunone_message_new_full_from_uri (uri, SOUP_METHOD_POST, content_type, SOUP_BUFFER_SYSTEM_OWNED,
+	msg = sunone_message_new_full_from_uri (uri, SOUP_METHOD_POST, content_type, SOUP_MEMORY_TAKE,
 						import_msg, strlen (import_msg));
 
 	/* send the request to the server */
@@ -2329,13 +2328,13 @@ sunone_connection_import (SunOneConnection *connection, const char *calid, icalc
 	if (!SOUP_STATUS_IS_SUCCESSFUL (msg->status_code)) 
 		retval = msg->status_code;
 
-	if (msg->response.body) {
+	if (msg->response_body->data) {
 		if (IS_CNC_WCAP_2_0 (connection)) {
-			err = strstr (msg->response.body, "var errno=");
+			err = strstr (msg->response_body->data, "var errno=");
 			err += 10;
 		}
 		else {
-			err = strstr (msg->response.body, "X-NSCP-WCAP-ERRNO:");
+			err = strstr (msg->response_body->data, "X-NSCP-WCAP-ERRNO:");
 			err += 18;
 		}
 
@@ -2381,7 +2380,7 @@ sunone_connection_storeevents_by_mail (SunOneConnection *connection, const char
 {
 	SunOneConnectionPrivate *priv = connection->priv;
 	ECalComponent *comp;
-	SoupUri *fetch_uri;
+	SoupURI *fetch_uri;
 	SoupMessage *msg;
 	guint retval;
 	icalcomponent *real_icalcomp;
@@ -2575,7 +2574,7 @@ sunone_connection_storeevents_by_mail (SunOneConnection *connection, const char
 	retval = msg->status_code;
 
 	if (SUNONE_ERROR_IS_SUCCESSFUL (msg->status_code) && return_icalcomp) {
-		*return_icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
+		*return_icalcomp = sunone_util_icalparser_parse_string (msg->response_body->data, msg->response_body->length);
 		if (!*return_icalcomp)
 			retval = SOUP_STATUS_MALFORMED;
 	}
@@ -2617,7 +2616,7 @@ sunone_connection_storetodos (SunOneConnection *connection, const char *calid, i
 {
 	SunOneConnectionPrivate *priv = connection->priv;
 	ECalComponent *comp;
-	SoupUri *fetch_uri;
+	SoupURI *fetch_uri;
 	SoupMessage *msg;
 	guint retval;
 	icalcomponent *real_icalcomp;
@@ -2811,7 +2810,7 @@ sunone_connection_storetodos (SunOneConnection *connection, const char *calid, i
 	retval = msg->status_code;
 
 	if (SUNONE_ERROR_IS_SUCCESSFUL (msg->status_code) && return_icalcomp) {
-		*return_icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
+		*return_icalcomp = sunone_util_icalparser_parse_string (msg->response_body->data, msg->response_body->length);
 		if (!*return_icalcomp)
 			retval = SOUP_STATUS_MALFORMED;
 	}
@@ -2833,7 +2832,7 @@ sunone_connection_verifyevents_by_ids (SunOneConnection *connection,
 				       icalcomponent **icalcomp)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *fetch_uri;
+	SoupURI *fetch_uri;
 	SoupMessage *msg;
 	char *post_string, *content_type;
 	guint retval;
@@ -2859,14 +2858,14 @@ sunone_connection_verifyevents_by_ids (SunOneConnection *connection,
 	
 	content_type = "application/x-www-form-urlencoded";
 	/* send the request to the server */
-	msg = sunone_message_new_full_from_uri (fetch_uri, SOUP_METHOD_POST, content_type, SOUP_BUFFER_SYSTEM_OWNED,
+	msg = sunone_message_new_full_from_uri (fetch_uri, SOUP_METHOD_POST, content_type, SOUP_MEMORY_TAKE,
 		post_string, strlen (post_string));
 
 	sunone_message_send (connection, msg);
 	retval = msg->status_code;
 
 	if (SUNONE_ERROR_IS_SUCCESSFUL (msg->status_code)) {
-		*icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
+		*icalcomp = sunone_util_icalparser_parse_string (msg->response_body->data, msg->response_body->length);
 		if (!*icalcomp)
 			retval = SOUP_STATUS_MALFORMED;
 	}
@@ -2886,7 +2885,7 @@ sunone_connection_verifytodos_by_ids (SunOneConnection *connection,
 				      icalcomponent **icalcomp)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *fetch_uri;
+	SoupURI *fetch_uri;
 	SoupMessage *msg;
 	char *post_string, *content_type;
 	guint retval;
@@ -2911,14 +2910,14 @@ sunone_connection_verifytodos_by_ids (SunOneConnection *connection,
 	
 	content_type = "application/x-www-form-urlencoded";
 	/* send the request to the server */
-	msg = sunone_message_new_full_from_uri (fetch_uri, SOUP_METHOD_POST, content_type, SOUP_BUFFER_SYSTEM_OWNED,
+	msg = sunone_message_new_full_from_uri (fetch_uri, SOUP_METHOD_POST, content_type, SOUP_MEMORY_TAKE,
 		post_string, strlen (post_string));
 
 	sunone_message_send (connection, msg);
 	retval = msg->status_code;
 
 	if (SUNONE_ERROR_IS_SUCCESSFUL (msg->status_code)) {
-		*icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
+		*icalcomp = sunone_util_icalparser_parse_string (msg->response_body->data, msg->response_body->length);
 		if (!*icalcomp)
 			retval = SOUP_STATUS_MALFORMED;
 	}
@@ -2953,7 +2952,7 @@ guint
 sunone_connection_version (SunOneConnection *connection)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupUri *fetch_uri;
+	SoupURI *fetch_uri;
 	SoupMessage *msg;
 	guint retval;
 	icalcomponent *icalcomp;
@@ -2975,7 +2974,7 @@ sunone_connection_version (SunOneConnection *connection)
 	retval = msg->status_code;
 
 	if (SUNONE_ERROR_IS_SUCCESSFUL (msg->status_code)) {
-		icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
+		icalcomp = sunone_util_icalparser_parse_string (msg->response_body->data, msg->response_body->length);
 		if (!icalcomp)
 			retval = SOUP_STATUS_MALFORMED;
 		else {
@@ -3002,21 +3001,21 @@ sunone_connection_version (SunOneConnection *connection)
 	return retval;
 }
 
-SoupStatusClass
+guint
 sunone_message_send (SunOneConnection *connection, SoupMessage *msg)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
-	SoupStatusClass status_class;
+	guint status;
 
 	setup_message (msg);
-	status_class = soup_session_send_message (priv->soup_session, msg);
-	if (status_class != SOUP_STATUS_CLASS_TRANSPORT_ERROR)
-		parse_server_response (msg, &status_class);
+	status = soup_session_send_message (priv->soup_session, msg);
+	if (!SOUP_STATUS_IS_TRANSPORT_ERROR(status))
+		parse_server_response (msg, &status);
 
-	return status_class;
+	return status;
 }
 
-SoupStatusClass
+guint
 sunone_message_send_no_parse (SunOneConnection *connection, SoupMessage *msg)
 {
 	SunOneConnectionPrivate *priv = connection->priv;
