@@ -10,7 +10,12 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <string.h>
+#include <glib/gi18n.h>
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-moniker-util.h>
 #include <libgnomevfs/gnome-vfs.h>
@@ -524,9 +529,14 @@ sunone_invitation_list_model_poll_cb (gpointer data)
 	if (!model->props)
 		goto removal;
 
-	if (!sunone_util_has_permissions (model->props, sunone_connection_get_user (cnc), 
-					  SUNONE_ACE_CONTEXT_CALENDAR_COMPONENTS, 
-					  SUNONE_ACE_PERMISSION_READ | SUNONE_ACE_PERMISSION_REPLY))
+	if (!sunone_util_has_permissions (model->props,
+					sunone_connection_get_user (cnc), 
+					SUNONE_ACE_CONTEXT_CALENDAR_COMPONENTS, 
+					SUNONE_ACE_PERMISSION_READ | SUNONE_ACE_PERMISSION_REPLY) &&
+				!sunone_util_has_permissions (model->props,
+					sunone_connection_get_uid (cnc),
+					SUNONE_ACE_CONTEXT_CALENDAR_COMPONENTS, 
+					SUNONE_ACE_PERMISSION_READ | SUNONE_ACE_PERMISSION_REPLY))
 		goto removal;
 
 	/* Now fetch the invitations */
