@@ -10,7 +10,12 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <string.h>
+#include <glib/gi18n.h>
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-moniker-util.h>
 #include <bonobo/bonobo-stream-memory.h>
@@ -23,9 +28,9 @@
 #include <libecal/e-cal-time-util.h>
 #include <libedataserver/e-time-utils.h>
 #include <misc/e-cell-renderer-combo.h>
-#include "lib/sunone-account.h"
 #include "lib/sunone-util.h"
 #include "evolution-calendar.h"
+#include "sunone-account.h"
 #include "sunone-invitation-list.h"
 #include "sunone-itip-view.h"
 
@@ -178,7 +183,7 @@ set_data (BonoboWidget *control, const char *string)
 		       "IDL:Bonobo/PersistStream:1.0", &ev);
 			
 	if (persist == CORBA_OBJECT_NIL) {
-			gtk_object_sink (GTK_OBJECT (control));
+			g_object_ref_sink (G_OBJECT (control));
 			return ;
 	}
 
@@ -525,9 +530,13 @@ setup_invitation_list (SunOneInvitationList *list)
 
 	renderer = e_cell_renderer_combo_new ();
 	editable = sunone_util_has_permissions (priv->model->props, 
-				sunone_account_get_user (priv->model->account),
-				SUNONE_ACE_CONTEXT_CALENDAR_COMPONENTS, 
-				SUNONE_ACE_PERMISSION_WRITE | SUNONE_ACE_PERMISSION_REPLY);
+					sunone_account_get_user (priv->model->account),
+					SUNONE_ACE_CONTEXT_CALENDAR_COMPONENTS, 
+					SUNONE_ACE_PERMISSION_WRITE | SUNONE_ACE_PERMISSION_REPLY) ||
+				sunone_util_has_permissions (priv->model->props, 
+					sunone_account_get_uid (priv->model->account),
+					SUNONE_ACE_CONTEXT_CALENDAR_COMPONENTS, 
+					SUNONE_ACE_PERMISSION_WRITE | SUNONE_ACE_PERMISSION_REPLY);
 	g_object_set (G_OBJECT (renderer), "list", strings, "editable", editable, NULL);
 	gtk_tree_view_insert_column_with_attributes (priv->treeview, 
 						-1, 
